domain

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 1, 2026 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Overview

Copyright © 2026 Soner Astan astansoner@gmail.com

Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.

Copyright © 2026 Soner Astan astansoner@gmail.com

Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type DummyConfig

type DummyConfig struct {
	Host string
	Port int
}

func NewDummyConfig

func NewDummyConfig() *DummyConfig

type ReportService

type ReportService struct {
	flora.Component
	// contains filtered or unexported fields
}

func NewReportService

func NewReportService(docFactory func() (report.DocumentGenerator, func(), error)) *ReportService

func (*ReportService) CreateMonthlyReport

func (s *ReportService) CreateMonthlyReport(month string)

type UserRepository

type UserRepository interface {
	GetUserName() string
}

type UserService

type UserService struct {
	flora.Component `flora:"constructor=BuildUserService"`
	// contains filtered or unexported fields
}

func BuildUserService

func BuildUserService(repo UserRepository, cfg config.Config) *UserService

func (*UserService) PrintUser

func (s *UserService) PrintUser()

Jump to