report

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 1, 2026 License: Apache-2.0 Imports: 3 Imported by: 0

Documentation

Overview

Copyright © 2026 Soner Astan astansoner@gmail.com

Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type DocumentGenerator

type DocumentGenerator interface {
	Generate(title string) string
}

type NonPrimaryDocumentGenerator

type NonPrimaryDocumentGenerator struct {
	flora.Component `flora:"scope=prototype"`
	// contains filtered or unexported fields
}

func NewNonPrimaryDocumentGenerator

func NewNonPrimaryDocumentGenerator(cfg config.Config) (*NonPrimaryDocumentGenerator, func(), error)

func (*NonPrimaryDocumentGenerator) Generate

func (p *NonPrimaryDocumentGenerator) Generate(title string) string

type PdfGenerator

type PdfGenerator struct {
	flora.Component `flora:"scope=prototype,primary"`
	// contains filtered or unexported fields
}

func NewPdfGenerator

func NewPdfGenerator(cfg config.Config) (*PdfGenerator, func(), error)

func (*PdfGenerator) Generate

func (p *PdfGenerator) Generate(title string) string

Jump to