scanner

package
v1.0.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 7, 2026 License: Apache-2.0 Imports: 14 Imported by: 0

Documentation

Overview

Copyright © 2026 Soner Astan astansoner@gmail.com

Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.

Copyright © 2026 Soner Astan astansoner@gmail.com

Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.

Index

Constants

const (
	ScopeSingleton = "singleton"
	ScopePrototype = "prototype"

	ComponentMarker     = "github.com/soner3/flora.Component"
	ConfigurationMarker = "github.com/soner3/flora.Configuration"
)

Variables

var (
	ErrProviderFuncNotFound = errors.New("provider not found")
	ErrInvalidProviderFunc  = errors.New("invalid provider func")
	ErrInterfaceCollision   = errors.New("interface collision")
	ErrInvalidInterface     = errors.New("invalid interface")
	ErrNoImplementation     = errors.New("no component implements interface")
	ErrInvalidSlice         = errors.New("invalid slice")
	ErrInvalidMetadata      = errors.New("invalid metadata")
)
var (
	ErrLoadPackages = errors.New("failed to load packages")
	ErrCompile      = errors.New("compile error in package")
)

Functions

func ParsePackages

func ParsePackages(pkgs []*packages.Package) (*engine.GeneratorContext, error)

ParsePackages parses the given packages and returns a GeneratorContext containing the parsed components and slice bindings

func ScanPackages

func ScanPackages(rootDir string) ([]*packages.Package, error)

Types

This section is empty.

Jump to